@@ -47,6 +47,8 @@ public:
   int fwdDecl(const FwdDecl& f);
   int fwdDeclRef(FwdDecl& f);
 
+  mode_t dummyFunc(QObject* parent) { return 0; }
+
 signals:
   void publicSlotCalled();
 
@@ -93,6 +95,8 @@ private:
   Q_DISABLE_COPY(NonCopyableByMacro)
 };
 
+Q_DECLARE_METATYPE(NonCopyableByMacro*)
+
 class HasPrivateDefaultCtor
 {
 public:
@@ -113,3 +117,8 @@ private:
 };
 
 }
+
+enum __attribute__((visibility("default"))) EnumWithAttributes {
+    Foo,
+    Bar = 2
+};
